@@ -6,10 +6,9 @@
 # instead choose to run each of the .SH files by yourself, or "Configure -S".
 #
 
-# Configuration time: Tue Sep 26 14:54:17 BST 1995
-# Configured by: ian
-# Target system: linux chiark 1.1.11 #3 wed may 4 09:53:09 bst 1994 i486 
-# modified for to use libncurses, mrn 23 May 96
+# Configuration time: Fri Nov 17 19:50:28 GMT 2000
+# Configured by: mcv21
+# Target system: linux pick 2.2.14 #1 wed jan 12 13:49:58 gmt 2000 i686 unknown 
 
 d_bsd='undef'
 d_eunice='undef'
@@ -61,7 +60,7 @@ vi='vi'
 vspell=''
 who=''
 hint='previous'
-myuname='linux chiark 1.1.11 #3 wed may 4 09:53:09 bst 1994 i486 '
+myuname='linux pick 2.2.14 #1 wed jan 12 13:49:58 gmt 2000 i686 unknown '
 srcdir='.'
 vincludes=''
 vpath='.'
@@ -71,17 +70,17 @@ active='none'
 acttimes='nntp'
 d_acttimes='define'
 myactive='.falseactive'
-bin='/usr/bin'
-binexp='/usr/bin'
-installbin='/usr/bin'
+bin='/usr/lib/trn'
+binexp='/usr/lib/trn'
+installbin='/usr/lib/trn'
 cc='gcc'
 ccflags=''
 cppflags=''
 ldflags='-s'
 lkflags=''
 optimize='-O3'
-cf_by='ian'
-cf_time='Tue Sep 26 14:54:17 BST 1995'
+cf_by='mcv21'
+cf_time='Fri Nov 17 19:50:28 GMT 2000'
 contains='grep'
 cpplast='-'
 cppminus='-'
@@ -96,7 +95,7 @@ d_getpwent='define'
 d_getcwd='undef'
 d_getwd='define'
 d_havetlib='define'
-termlib='-lncurses'
+termlib='-lcurses'
 d_ignoreorg='undef'
 d_internet='define'
 d_memcmp='define'
@@ -121,7 +120,7 @@ d_portable='define'
 d_rdchk='undef'
 d_rename='define'
 d_sigblock='define'
-d_sighold='undef'
+d_sighold='define'
 d_sizet='undef'
 d_strccmp='define'
 d_strchr='define'
@@ -137,7 +136,7 @@ d_vfork='define'
 d_voidsig='define'
 signal_t='void'
 defeditor='/usr/bin/emacs'
-filexp='/usr/lib/trn/filexp'
+filexp='/usr/share/trn/filexp'
 d_dirnamlen=''
 i_dirent='define'
 i_ptem='undef'
@@ -154,8 +153,8 @@ i_sysndir='undef'
 i_sgtty='undef'
 i_termio='undef'
 i_termios='define'
-i_systime='define'
-i_time='undef'
+i_systime='undef'
+i_time='define'
 i_unistd='define'
 i_vfork='undef'
 ispell_options=''
@@ -173,10 +172,10 @@ orgdist='none'
 statedist='none'
 mailer='/usr/sbin/sendmail'
 mailfile='/var/spool/mail/%L'
-installmansrc='/usr/man/man1'
+installmansrc='/usr/share/man/man1'
 manext='1'
-mansrc='/usr/man/man1'
-mansrcexp='/usr/man/man1'
+mansrc='/usr/share/man/man1'
+mansrcexp='/usr/share/man/man1'
 mboxchar='F'
 c=''
 n='-n'
@@ -191,13 +190,13 @@ newsspool='/tmp'
 orgname='/etc/news/organization'
 package='trn'
 spackage='Trn'
-pager='/bin/more'
+pager='/usr/bin/pager'
 phost='/etc/news/whoami'
 phostcmd=''
 prefshell='/bin/sh'
-installprivlib='/usr/lib/trn'
-privlib='/usr/lib/trn'
-privlibexp='/usr/lib/trn'
+installprivlib='/usr/share/trn'
+privlib='/usr/share/trn'
+privlibexp='/usr/share/trn'
 rootid='0'
 sharpbang='#!'
 shsharp='true'
